@@ -85,14 +85,35 @@ class Option(object):
         except exc:
             return Empty()
 
+    def map(self, callback):
+        raise NotImplementedError()
+
+    def filter(self, callback):
+        raise NotImplementedError()
+
+    def get_or(self, default):
+        raise NotImplementedError()
+
+    def get_or_call(self, callback, *args, **kwargs):
+        raise NotImplementedError()
+
+    def or_else(self, default):
+        raise NotImplementedError()
+
+    def or_call(self, callback, *args, **kwargs):
+        raise NotImplementedError()
+
 class Full(Option):
     """Represents value that is ready for further computations"""
 
     __slots__ = "x", 
     empty = False 
 
-    def __new__(tp, *args, **kwargs):
-        return object.__new__(tp)
+    def __new__(tp, value, *args, **kwargs):
+        # Full(Empty) -> Full
+        if isinstance(value, Empty):
+            return Empty()
+        return object.__new__(tp) 
 
     def __init__(self, value, *args):
         # Option(Full) -> Full
