@@ -61,6 +61,15 @@ class OperatorTestCase(unittest.TestCase):
         self.assertEqual(100, 
                          op.foldr(op.call, 0)([lambda s: s**2, lambda k: k+10]))
 
+    def test_unfold_infinite(self):
+        doubler = op.unfold(lambda x: (x*2, x*2))
+        self.assertEqual(20, next(doubler(10)))
+        self.assertEqual([20, 40, 80, 160, 320], list(iters.take(5, doubler(10))))
+
+    def test_unfold_finite(self):
+        countdown = op.unfold(lambda x: (x-1, x-2) if x > 1 else None)
+        self.assertEqual([9,7,5,3,1], list(countdown(10)))
+
 class UnderscoreTestCase(unittest.TestCase):
 
     def test_identity_default(self):
@@ -177,6 +186,15 @@ class UnderscoreTestCase(unittest.TestCase):
         self.assertEqual(["test", "case"], (_.call("split"))("test case"))
         self.assertEqual("str", _.__name__(str))
 
+    def test_call_method_args(self):
+        self.assertEqual(["test", "case"], (_.call("split", "-"))("test-case"))
+        self.assertEqual(["test-case"], (_.call("split", "-", 0))("test-case"))
+
+    def test_call_method_kwargs(self):
+        test_dict = {'num': 23}
+        _.call("update", num = 42)(test_dict)
+        self.assertEqual({'num': 42}, (test_dict))
+
     def test_comparator(self):
         self.assertTrue((_ < 7)(1))
         self.assertFalse((_ < 7)(10))
@@ -412,6 +430,21 @@ class IteratorsTestCase(unittest.TestCase):
 
         self.assertEqual([2,3], list(iters.tail(gen())))
 
+    def test_compact(self):
+        self.assertEqual([True, 1, 0.1, "non-empty", [""], (0,), {"a": 1}],
+                         list(iters.compact([None, False, True, 0, 1, 0.0, 0.1,
+                                             "", "non-empty", [], [""],
+                                             (), (0,), {}, {"a": 1}])))
+
+    def test_reject(self):
+        self.assertEqual([1, 3, 5, 7, 9],
+                         list(iters.reject(_ % 2 == 0, range(1, 11))))
+        self.assertEqual([None, False, 0, 0.0, "", [], (), {}],
+                         list(iters.reject(None, [None, False, True, 0, 1,
+                                                  0.0, 0.1, "", "non-empty",
+                                                  [], [""], (), (0,),
+                                                  {}, {"a": 1}])))
+
     def test_padnone(self):
         it = iters.padnone([10,11])
         self.assertEqual(10, next(it))
@@ -568,6 +601,14 @@ class StreamTestCase(unittest.TestCase):
         # 35 elements should be already evaluated
         self.assertEqual(fib.cursor(), 35)
 
+    def test_origin_param(self):
+        self.assertEqual([100], list(Stream(100)))
+        self.assertEqual([1,2,3], list(Stream(1, 2, 3)))
+        self.assertEqual([1,2,3,10,20,30], list(Stream(1, 2, 3) << [10,20,30]))
+
+    def test_origin_param_string(self):
+        self.assertEqual(["stream"], list(Stream("stream")))
+
 class OptionTestCase(unittest.TestCase, InstanceChecker):
 
     def test_create_option(self):
@@ -686,6 +727,12 @@ class OptionTestCase(unittest.TestCase, InstanceChecker):
                          monad.Option.from_call(lambda d, k: d[k], 
                                                 {"a":1}, "b", exc=KeyError))
 
+    def test_flatten_operation(self):
+        self.assertEqual(monad.Empty(), monad.Empty(monad.Empty()))
+        self.assertEqual(monad.Empty(), monad.Empty(monad.Full(10)))
+        self.assertEqual(monad.Empty(), monad.Full(monad.Empty()))
+        self.assertEqual("Full(20)", str(monad.Full(monad.Full(20))))
+
 class TrampolineTestCase(unittest.TestCase):
 
     def test_tco_decorator(self):
